@@ -1,15 +1,18 @@
+"""
+It is a test file that checks the package working.
+"""
 import os
-import sys
 import random
 
-is_all_test_success = True
-print("\033[94mChecking the installation of the package ...\033[0m")
+IS_ALL_TESS_SUCCESS = True
+print("\n\033[94mChecking the installation of the package ...\033[0m")
 try:
     from pypi_learn.youtube_srt_mp3 import YoutubeSrtMp3
+
     print("\033[0;32;49mThe module is imported SUCCESSFULLY\033[0m")
 except ImportError as module_not_installed:
     print('\033[91m' + module_not_installed.name + "\033[0m module is not found")
-    is_all_test_success = False
+    IS_ALL_TESS_SUCCESS = False
 NUM_SUBTITLES = 193  # total number of the subtitles
 TEST_SRT_FILE_PATH = "test/test_srt_file/Ot0vYkRT1Mg.srt"
 DOWNLOAD_PATH = "test/test_downloads_cropped"
@@ -25,7 +28,7 @@ def read_test_srt_file():
 
     # To test random subtitle
     def _test_compare_random_subs():
-        # generate random number to check 
+        # generate random number to check
         num_rand = random.randint(0, NUM_SUBTITLES)
         # get subtitle from the cropped file
         sub_from_the_random_txt_file = open(PATH_CROPPED_FILE + "/Ot0vYkRT1Mg_crop_"
@@ -66,44 +69,52 @@ def test_total_number_of_cropped_files():
     return total_num_srt + total_num_mp3 == NUM_SUBTITLES * 2 + 1
 
 
-def main(is_all_test_success=None):
-    success_count=0
-    if is_all_test_success is  False:
+def main():
+    """
+    it tests and prints the results.
+    """
+    success_count = 0
+    if IS_ALL_TESS_SUCCESS is False:
         print("\033[91m Please check the module name to pass other test!\033[0m")
     else:
-        success_count+=1
-        print("##########################################################################\n")
+        success_count += 1
+        # print("##########################################################################\n")
         # test download and cropped files
-        print("\033[94mChecking to crop and download files...\033[0m")
+        print("\n\033[94mChecking to crop and download files...\033[0m")
         if _download_crop_files() is False:
             print("\033[91mSomething went wrong while downloading or cropping files. \033[0m")
         else:
-            success_count+=1
-            print("\033[0;32;49mDownloading and cropping are SUCCESSFULLY done!"
-                  "SUCCESSFULLY PASSED\033[0m")
-        print("##########################################################################\n")
+            success_count += 1
+            print("\033[0;32;49mDownloading and cropping are  DONE!"
+                  "PASSED\033[0m")
+        # print("##########################################################################\n")
 
-        print("\033[94mChecking the total number of downloaded and cropped files...\033[0m")
+        print("\n\033[94mChecking the total number of downloaded and cropped files...\033[0m")
         if test_total_number_of_cropped_files() is False:
-            print("\033[91mThe total number of files does not equal to real total files number. \033[0m")
+            print("\033[91mThe total number of files does not "
+                  "equal to real total files number. \033[0m")
         else:
-            success_count+=1
-            print("\033[0;32;49mThe total number of files is EQUAL. SUCCESSFULLY PASSED!\033[0m")
+            success_count += 1
+            print("\033[0;32;49mThe total number of files is EQUAL. PASSED!\033[0m")
         # test the random subtitle between real sub and downloaded file
-        print("##########################################################################\n")
+        # print("##########################################################################\n")
 
-        print("\033[94mComparing the random text which is downloaded "
+        print("\n\033[94mComparing the random text which is downloaded "
               "in the previous test with the real subtitle...\033[0m")
         if read_test_srt_file() is False:
-            print("\033[91m.FAILED! Two compared subtitles aren't equal.\033[0m")
+            print("\033[91mFAILED! Two compared subtitles aren't equal.\033[0m")
         else:
-            success_count+=1
-            print("\033[0;32;49m Two compared subtitles are EQUAL. SUCCESSFULLY PASSED\033[0m")
-        print("##########################################################################\n")
-    
-    if success_count<4:
-        raise Exception("FAILED! Not PASSED " +str(4-success_count)+" tests.")
+            success_count += 1
+            print("\033[0;32;49m Two compared subtitles are EQUAL. PASSED\033[0m")
+        # print("##########################################################################\n")
+
+    print("\n\033[94m##########################################################################\033[0m")
+    print("\033[0;32;49m\t\t" + str(success_count) + " of the 4 tests were PASSED\033[0m")
+    print("\033[94m##########################################################################\033[0m\n")
+    if success_count < 4:
+        message_error = "\033[91mFAILED! Not PASSED " + str(4 - success_count) + " tests.\033[0m"
+        raise Exception(message_error)
 
 
 if __name__ == '__main__':
-    main(is_all_test_success)
+    main()
